class Chef
  class Provider::FirewallRouter < Chef::Provider::LWRPBase
    include Firehol::Helpers

    provides :firewall_router

    def whyrun_supported?
      true
    end

    attributes = %i(inface masquerade outface reverse_masquerade protocol)
    action :create do
      firewall = {
        inface:             new_resource.inface,
        masquerade:         new_resource.masquerade,
        outface:            new_resource.outface,
        reverse_masquerade: new_resource.reverse_masquerade,
        type:               format_type("router", new_resource.protocol)
      }

      # TODO: unify with interface
      router = node["firewall"]["interfaces"][new_resource.common_name]
      if !router || router.symbolize_keys.slice(*attributes) != firewall
        converge_by("Update/create #{new_resource.common_name} router") do
          node.normal["firewall"]["interfaces"][new_resource.common_name].tap do |details|
            firewall.keys.each do |key|
              details[key] = firewall[key]
            end
            details["rules"] = {} unless details["rules"]
            details["router"] = true
          end

          firewall_resource = run_context.resource_collection.find(firewall: "firehol")
          raise "could not find a firewall resource" unless firewall_resource
          new_resource.notifies(:restart, firewall_resource, :delayed)
        end
      end
    end
  end
end
